@@ -24,9 +24,10 @@
 
 #include "../daemon/actions/bundled/suspendsession.h"
 
+#include "powerdevilpowermanagement.h"
+
 #include <KConfigGroup>
 #include <KActivities/Consumer>
-#include <Solid/PowerManagement>
 #include <Solid/Battery>
 #include <Solid/Device>
 #include <actioneditwidget.h>
@@ -91,13 +92,11 @@ void ActivityWidget::load()
 
     using namespace PowerDevil::BundledActions;
 
-    QSet< Solid::PowerManagement::SleepState > methods = Solid::PowerManagement::supportedSleepStates();
-
-    if (methods.contains(Solid::PowerManagement::SuspendState)) {
+    if (PowerDevil::PowerManagement::instance()->canSuspend()) {
         m_ui->alwaysActionBox->addItem(QIcon::fromTheme("system-suspend"),
                                        i18n("Suspend"), (uint)SuspendSession::ToRamMode);
     }
-    if (methods.contains(Solid::PowerManagement::HibernateState)) {
+    if (PowerDevil::PowerManagement::instance()->canHibernate()) {
         m_ui->alwaysActionBox->addItem(QIcon::fromTheme("system-suspend-hibernate"),
                                        i18n("Hibernate"), (uint)SuspendSession::ToDiskMode);
     }
@@ -199,6 +198,3 @@ void ActivityWidget::setChanged()
 {
     Q_EMIT changed(true);
 }
-
-
-#include "activitywidget.moc"
